from wagtail.blocks import (
    CharBlock,
    IntegerBlock,
    ListBlock,
    PageChooserBlock,
    RichTextBlock,
    StructBlock,
    TextBlock,
    URLBlock,
)
from wagtail.images.blocks import ImageChooserBlock


class ElectionsCarouselBlock(StructBlock):
    image = ImageChooserBlock(label="Obrázek na pozadí")

    class Meta:
        template = "styleguide2/includes/molecules/menus/elections/carousel.html"
        icon = "form"
        label = "Carousel"


class CandidateBlock(StructBlock):
    page = PageChooserBlock(
        label="Stránka", page_type=["elections.ElectionsCandidatePage"]
    )

    image = ImageChooserBlock(
        label="Obrázek",
        help_text="Pokud není vybrán, použije se obrázek ze stránky kandidáta",
        required=False,
    )

    description = TextBlock(
        label="Popis",
    )

    class Meta:
        template = "styleguide2/includes/molecules/candidates/elections/candidate_primary_box.html"
        icon = "form"
        label = "Kandidát"


class CandidateListBlock(StructBlock):
    candidates = ListBlock(
        CandidateBlock(),
        label="Kandidáti",
    )

    class Meta:
        template = "styleguide2/includes/organisms/candidates/elections/candidate_primary_list.html"
        icon = "form"
        label = "Seznam kandidátů"


class ProgramCategoryItemBlock(StructBlock):
    number = IntegerBlock(label="Číslo")

    content = TextBlock(label="Obsah")

    class Meta:
        icon = "form"
        label = "Bod"


class ProgramCategoryBlock(StructBlock):
    number = IntegerBlock(label="Číslo")

    name = CharBlock(label="Název")

    points = ListBlock(ProgramCategoryItemBlock(), label="Body")

    class Meta:
        icon = "form"
        label = "Kategorie"


class ProgramBlock(StructBlock):
    categories = ListBlock(ProgramCategoryBlock(), label="Kategorie")

    long_version_url = URLBlock(label="Odkaz na celou verzi programu")
    long_version_text = CharBlock(label="Nadpis odkazu na celou verzi programu")

    class Meta:
        icon = "form"
        label = "Vyskakovací program"
        template = "styleguide2/includes/molecules/program/card_program.html"


class PersonFaqAnswerBlock(StructBlock):
    question = CharBlock(label="Otázka")

    answer = TextBlock(label="Odpověď")

    class Meta:
        icon = "form"
        label = "Odpověď kandidáta na otázku"


class PersonFaqAnswersBlock(StructBlock):
    section_name = CharBlock(
        label="Název sekce", help_text="Např. 'Otevřenost a transparentnost'"
    )

    topic = CharBlock(label="Téma", help_text="Např. 'téma Markéty Gregorové'")

    person_page = PageChooserBlock(
        label="Stránka kandidáta", page_type=["elections.ElectionsCandidatePage"]
    )

    image = ImageChooserBlock(
        label="Obrázek",
        help_text="Pokud není vybrán, použije se obrázek ze stránky kandidáta",
        required=False,
    )

    questions = ListBlock(PersonFaqAnswerBlock(label="Odpověď"), label="Otázky")

    class Meta:
        icon = "form"
        label = "Odpovědi kandidáta na otázky"
        template = "styleguide2/includes/organisms/faq/faq_answer.html"
